==> neo4j-kernel-3.3.1-sources.jar: org/neo4j/kernel/impl/util/watcher/FileSystemWatcherService.java <==
/*
 * Copyright (c) 2002-2017 "Neo Technology,"
 * Network Engine for Objects in Lund AB [http://neotechnology.com]
 *
 * This file is part of Neo4j.
 *
 * Neo4j is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package org.neo4j.kernel.impl.util.watcher;

import org.neo4j.io.fs.watcher.FileWatcher;
import org.neo4j.kernel.lifecycle.Lifecycle;

/**
 * Interface to be able to recognise file system watcher service in the set of discoverable services,
 * need to extend {@link Lifecycle} since service should be restartable in clustering setup
 * (for example during store branching)
 */
public interface FileSystemWatcherService extends Lifecycle
{
    FileSystemWatcherService EMPTY_WATCHER = new FileSystemWatcherService()
    {
        @Override
        public FileWatcher getFileWatcher()
        {
            return FileWatcher.SILENT_WATCHER;
        }

        @Override
        public void init() throws Throwable
        {
        }

        @Override
        public void start() throws Throwable
        {
        }

        @Override
        public void stop() throws Throwable
        {
        }

        @Override
        public void shutdown() throws Throwable
        {
        }
    };

    FileWatcher getFileWatcher();

}

==> neo4j-kernel-3.5.9-sources.jar: org/neo4j/kernel/impl/util/watcher/FileSystemWatcherService.java <==
/*
 * Copyright (c) 2002-2019 "Neo4j,"
 * Neo4j Sweden AB [http://neo4j.com]
 *
 * This file is part of Neo4j.
 *
 * Neo4j is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package org.neo4j.kernel.impl.util.watcher;

import org.neo4j.io.fs.watcher.FileWatcher;
import org.neo4j.kernel.lifecycle.Lifecycle;

/**
 * Interface to be able to recognise file system watcher service in the set of discoverable services,
 * need to extend {@link Lifecycle} since service should be restartable in clustering setup
 * (for example during store branching)
 */
public interface FileSystemWatcherService extends Lifecycle
{
    FileSystemWatcherService EMPTY_WATCHER = new FileSystemWatcherService()
    {
        @Override
        public FileWatcher getFileWatcher()
        {
            return FileWatcher.SILENT_WATCHER;
        }

        @Override
        public void init()
        {
        }

        @Override
        public void start()
        {
        }

        @Override
        public void stop()
        {
        }

        @Override
        public void shutdown()
        {
        }
    };

    FileWatcher getFileWatcher();

}
